==> funcnodes_span-0.1.1.tar.gz: funcnodes_span-0.1.1/funcnodes_span/smoothing.py <==
from funcnodes import NodeDecorator, Shelf
import numpy as np
import pandas as pd
from enum import Enum
from scipy.signal import savgol_filter, medfilt
from scipy.ndimage import gaussian_filter1d
import warnings

warnings.filterwarnings("ignore")

class SmoothMode(Enum):
    SAVITZKY_GOLAY = "savgol"
    GAUSSIAN = "gaussian"
    MOVING_AVERAGE = "ma"
    EXPONENTIAL_MOVING_AVERAGE = "ema"
    MEDIAN = "median"
    
    @classmethod
    def default(cls) -> 'SmoothMode':
        """Returns the default smoothing mode."""
        return cls.SAVITZKY_GOLAY

@NodeDecorator("span.basics.smooth", name="Smoothing")

def _smooth(array: np.ndarray, mode: SmoothMode = SmoothMode.default(), window: int = 5) -> np.ndarray:
    # """
    # Apply different smoothing techniques to the input array.

    # Args:
    #     array (np.ndarray): The input array to be smoothed.
    #     mode (SmoothMode): The smoothing mode to apply. Defaults to SmoothMode.SAVITZKY_GOLAY.
    #     window (int): The window size for the smoothing function. Defaults to 5.

    # Returns:
    #     np.ndarray: The smoothed array.

    # Raises:
    #     ValueError: If an unsupported smoothing mode is provided.
    # """
    
    def smooth_savgol(x: np.ndarray) -> np.ndarray:
        return savgol_filter(x, window, 2)
    
    def smooth_gaussian(x: np.ndarray) -> np.ndarray:
        return gaussian_filter1d(x, window)
    
    def smooth_ma(x: np.ndarray) -> np.ndarray:
        if x.ndim > 1:
            n, m = x.shape
            result = np.zeros((n, m))
            for i in range(n):
                result[i, :] = np.convolve(x[i, :], np.ones(window) / window, mode="same")
            return result
        else:
            return np.convolve(x, np.ones(window) / window, mode="same")
    
    def smooth_ema(x: np.ndarray) -> np.ndarray:
        if x.ndim > 1:
            n, m = x.shape
            result = np.zeros((n, m))
            for i in range(n):
                result[i, :] = pd.Series(x[i, :]).ewm(span=window).mean().values
            return result
        else:
            return pd.Series(x).ewm(span=window).mean().values
    
    def smooth_median(x: np.ndarray) -> np.ndarray:
        return medfilt(x, window)
    
    smoothing_methods = {
        SmoothMode.SAVITZKY_GOLAY: smooth_savgol,
        SmoothMode.GAUSSIAN: smooth_gaussian,
        SmoothMode.MOVING_AVERAGE: smooth_ma,
        SmoothMode.EXPONENTIAL_MOVING_AVERAGE: smooth_ema,
        SmoothMode.MEDIAN: smooth_median
    }
    
    if mode not in smoothing_methods:
        raise ValueError(f"Unsupported smoothing mode: {mode}")
    
    return smoothing_methods[mode](array)


# @NodeDecorator("span.basics.smooth.savgol", name="Savgol")
# def _smooth_savgol(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Savitzky-Golay smoothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """

#     array_o = savgol_filter(array, window, 2)

#     return array_o


# @NodeDecorator("span.basics.smooth.gaussian", name="Gaussian")
# def _smooth_gaussian(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Gaussians moothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """

#     array_o = gaussian_filter1d(array, window)

#     return array_o


# @NodeDecorator("span.basics.smooth.ma", name="Moving average")
# def _smooth_ma(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Moving Average moothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """

#     if array.ndim > 1:
#         n, m = array.shape
#         array_o = np.zeros((n, m))
#         for i in range(n):
#             array_o[i, :] = np.convolve(
#                 array[i, :], np.ones(window) / window, mode="same"
#             )
#     else:
#         array_o = np.convolve(array, np.ones(window) / window, mode="same")

#     return array_o


# @NodeDecorator(
#     "span.basics.smooth.ema", name="Exponential moving average"
# )
# def _smooth_ema(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Exponential Moving Average moothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """
#     if array.ndim > 1:
#         n, m = array.shape
#         array_o = np.zeros((n, m))
#         for i in range(n):
#             array_o[i, :] = pd.Series(array[i, :]).ewm(span=window).mean().values
#     else:
#         array_o = pd.Series(array).ewm(span=window).mean().values

#     return array_o


# @NodeDecorator("span.basics.smooth.median", name="Median")
# def _smooth_median(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Median smoothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """

#     array_o = medfilt(array, window)

#     return array_o


SMOOTH_NODE_SHELF = Shelf(
    nodes=[_smooth],
    subshelves=[],
    name="Smoothing",
    description="Smoothing of the spectra",
)

==> funcnodes_span-0.1.7.tar.gz: funcnodes_span-0.1.7/funcnodes_span/smoothing.py <==
from funcnodes import NodeDecorator, Shelf
import numpy as np
import pandas as pd
from enum import Enum
from scipy.signal import savgol_filter, medfilt
from scipy.ndimage import gaussian_filter1d
import warnings

warnings.filterwarnings("ignore")

class SmoothMode(Enum):
    SAVITZKY_GOLAY = "savgol"
    GAUSSIAN = "gaussian"
    MOVING_AVERAGE = "ma"
    EXPONENTIAL_MOVING_AVERAGE = "ema"
    MEDIAN = "median"
    
    @classmethod
    def default(cls) -> 'SmoothMode':
        """Returns the default smoothing mode."""
        return cls.SAVITZKY_GOLAY.value

@NodeDecorator("span.basics.smooth", name="Smoothing")

def _smooth(array: np.ndarray, mode: SmoothMode = SmoothMode.default(), window: int = 5) -> np.ndarray:
    # """
    # Apply different smoothing techniques to the input array.

    # Args:
    #     array (np.ndarray): The input array to be smoothed.
    #     mode (SmoothMode): The smoothing mode to apply. Defaults to SmoothMode.SAVITZKY_GOLAY.
    #     window (int): The window size for the smoothing function. Defaults to 5.

    # Returns:
    #     np.ndarray: The smoothed array.

    # Raises:
    #     ValueError: If an unsupported smoothing mode is provided.
    # """
    if isinstance(mode, SmoothMode):
        mode = mode.value
    def smooth_savgol(x: np.ndarray) -> np.ndarray:
        return savgol_filter(x, window, 2)
    
    def smooth_gaussian(x: np.ndarray) -> np.ndarray:
        return gaussian_filter1d(x, window)
    
    def smooth_ma(x: np.ndarray) -> np.ndarray:
        if x.ndim > 1:
            n, m = x.shape
            result = np.zeros((n, m))
            for i in range(n):
                result[i, :] = np.convolve(x[i, :], np.ones(window) / window, mode="same")
            return result
        else:
            return np.convolve(x, np.ones(window) / window, mode="same")
    
    def smooth_ema(x: np.ndarray) -> np.ndarray:
        if x.ndim > 1:
            n, m = x.shape
            result = np.zeros((n, m))
            for i in range(n):
                result[i, :] = pd.Series(x[i, :]).ewm(span=window).mean().values
            return result
        else:
            return pd.Series(x).ewm(span=window).mean().values
    
    def smooth_median(x: np.ndarray) -> np.ndarray:
        return medfilt(x, window)
    
    smoothing_methods = {
        SmoothMode.SAVITZKY_GOLAY.value: smooth_savgol,
        SmoothMode.GAUSSIAN.value: smooth_gaussian,
        SmoothMode.MOVING_AVERAGE.value: smooth_ma,
        SmoothMode.EXPONENTIAL_MOVING_AVERAGE.value: smooth_ema,
        SmoothMode.MEDIAN.value: smooth_median
    }
    
    if mode not in smoothing_methods.keys():
        raise ValueError(f"Unsupported smoothing mode: {mode}")
    
    return smoothing_methods[mode](array)


# @NodeDecorator("span.basics.smooth.savgol", name="Savgol")
# def _smooth_savgol(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Savitzky-Golay smoothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """

#     array_o = savgol_filter(array, window, 2)

#     return array_o


# @NodeDecorator("span.basics.smooth.gaussian", name="Gaussian")
# def _smooth_gaussian(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Gaussians moothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """

#     array_o = gaussian_filter1d(array, window)

#     return array_o


# @NodeDecorator("span.basics.smooth.ma", name="Moving average")
# def _smooth_ma(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Moving Average moothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """

#     if array.ndim > 1:
#         n, m = array.shape
#         array_o = np.zeros((n, m))
#         for i in range(n):
#             array_o[i, :] = np.convolve(
#                 array[i, :], np.ones(window) / window, mode="same"
#             )
#     else:
#         array_o = np.convolve(array, np.ones(window) / window, mode="same")

#     return array_o


# @NodeDecorator(
#     "span.basics.smooth.ema", name="Exponential moving average"
# )
# def _smooth_ema(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Exponential Moving Average moothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """
#     if array.ndim > 1:
#         n, m = array.shape
#         array_o = np.zeros((n, m))
#         for i in range(n):
#             array_o[i, :] = pd.Series(array[i, :]).ewm(span=window).mean().values
#     else:
#         array_o = pd.Series(array).ewm(span=window).mean().values

#     return array_o


# @NodeDecorator("span.basics.smooth.median", name="Median")
# def _smooth_median(array: np.array, window: int = 5) -> np.array:
#     """
#     Apply Median smoothing to the input array.

#     Args:
#         window (int): Parameter passed to scipy.signal.savgol_filter function

#     Returns:
#         array_o (np.array): Smoothed array
#     """

#     array_o = medfilt(array, window)

#     return array_o


SMOOTH_NODE_SHELF = Shelf(
    nodes=[_smooth],
    subshelves=[],
    name="Smoothing",
    description="Smoothing of the spectra",
)
